================
Release notes
================

Current release: |codename| (|version|)

Read the `CHANGELOG.md`_ at GitHub for more information.

.. _CHANGELOG.md: https://github.com/robinandeer/chanjo/blob/master/CHANGELOG.md
